@@ -3,4 +3,4 @@
 In case of Django ever moving them around, only this file will need updating. No new migrations."""
 
 # pylint: disable=unused-import
-from django.forms import Select, NumberInput
+from django.forms import NumberInput, Select
